==> ugene_1.31.1+dfsg.orig.tar.xz: ugene-1.31.1/src/plugins_3rdparty/kalign/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>KalignDialog</name>
    <message>
        <location filename="../src/KalignDialog.ui" line="32"/>
        <source>Align with Kalign</source>
        <translation>Выравнивание с помощью Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="46"/>
        <source>Input and output</source>
        <translation>Входные и выходные данные</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="54"/>
        <source>Input file</source>
        <translation>Входной файл</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="64"/>
        <location filename="../src/KalignDialog.ui" line="81"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="71"/>
        <location filename="../src/KalignDialog.ui" line="307"/>
        <source>Output file</source>
        <translation>Выходной файл</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="99"/>
        <source>Advanced options</source>
        <translation>Дополнительные опции</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="114"/>
        <source>Gap open penalty</source>
        <translation>Штраф за открытие пробела</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="160"/>
        <source>Gap extension penalty</source>
        <translation>Штраф за промежуточный пробел</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="206"/>
        <source>Terminal gap penalty</source>
        <translation>Штраф за закрытие пробела</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="252"/>
        <source>Bonus score</source>
        <translation>Бонусные очки</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="295"/>
        <source>Translate to amino when aligning</source>
        <translation>Транслировать в амины в процессе выравнивания</translation>
    </message>
</context>
<context>
    <name>PairwiseAlignmentHirschbergOptionsPanelMainWidget</name>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="37"/>
        <source>Gap open penalty</source>
        <translation>Штраф за открытие пробела</translation>
    </message>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="57"/>
        <source>Gap extension penalty</source>
        <translation>Штраф за промежуточный пробел</translation>
    </message>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="77"/>
        <source>Terminate gap penalty</source>
        <translation>Штраф за закрытие пробела</translation>
    </message>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="97"/>
        <source>Bonus score</source>
        <translation>Бонусные очки</translation>
    </message>
</context>
<context>
    <name>U2::KalignAdapter</name>
    <message>
        <location filename="../src/KalignAdapter.cpp" line="54"/>
        <source>Internal Kalign error: %1</source>
        <translation>Внутренняя ошибка Kalign: %1</translation>
    </message>
</context>
<context>
    <name>U2::KalignAlignWithExtFileSpecifyDialogController</name>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="128"/>
        <source>Align</source>
        <translation>Выровнять</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="129"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="146"/>
        <source>Open an alignment file</source>
        <translation>Открыть выравнивание</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="160"/>
        <source>Save an multiple alignment file</source>
        <translation>Сохранить выранивание</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="193"/>
        <location filename="../src/KalignDialogController.cpp" line="196"/>
        <source>Kalign with Align</source>
        <translation>Выравнивание с помощью Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="194"/>
        <source>Input file is not set!</source>
        <translation>Входной файл не выбран!</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="197"/>
        <source>Output file is not set!</source>
        <translation>Выходной файл не указан!</translation>
    </message>
</context>
<context>
    <name>U2::KalignDialogController</name>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="63"/>
        <source>Align</source>
        <translation>Выровнять</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="64"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>U2::KalignGObjectRunFromSchemaTask</name>
    <message>
        <location filename="../src/KalignTask.cpp" line="261"/>
        <source>Workflow wrapper &apos;%1&apos;</source>
        <translation>Workflow wrapper &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="271"/>
        <source>KAlign align &apos;%1&apos;</source>
        <translation>Выравнивание с помощью Kalign &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::KalignGObjectTask</name>
    <message>
        <location filename="../src/KalignTask.cpp" line="152"/>
        <source>KALIGN align &apos;%1&apos;</source>
        <translation>Выравнивание с помощью Kalign &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::KalignMSAEditorContext</name>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="153"/>
        <source>Align with Kalign...</source>
        <translation>Выравнивание с помощью Kalign...</translation>
    </message>
</context>
<context>
    <name>U2::KalignPlugin</name>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="71"/>
        <source>Kalign</source>
        <translation>Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="72"/>
        <source>A port of Kalign package for multiple sequence alignment. Check http://msa.sbc.su.se for the original version</source>
        <translation>Встроенный в UGENE программный пакет для множественного выравнивания последовательности. Здесь http://msa.sbc.su.se находится оригинальная версия</translation>
    </message>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="82"/>
        <source>Align with Kalign...</source>
        <translation>Выравнивание с помощью Kalign...</translation>
    </message>
</context>
<context>
    <name>U2::KalignTask</name>
    <message>
        <location filename="../src/KalignTask.cpp" line="73"/>
        <source>KALIGN alignment</source>
        <translation>Выравнивание с помощью Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="93"/>
        <source>Unsupported alphabet: %1</source>
        <translation>Неподдерживаемый алфавит: %1</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="96"/>
        <source>Kalign alignment started</source>
        <translation>Kalign alignment started</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="101"/>
        <source>Kalign alignment successfully finished</source>
        <translation>Kalign alignment successfully finished</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::KalignPrompter</name>
    <message>
        <location filename="../src/KalignWorker.cpp" line="121"/>
        <source> from %1</source>
        <translation> из %1</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="123"/>
        <source>Aligns each MSA supplied &lt;u&gt;%1&lt;/u&gt; with &quot;&lt;u&gt;Kalign&lt;/u&gt;&quot;.</source>
        <translation>Для каждого МВ &lt;u&gt;%1&lt;/u&gt;, построить выравнивание с использованием &lt;u&gt;&quot;Kalign&quot;&lt;/u&gt;.</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::KalignWorker</name>
    <message>
        <location filename="../src/KalignWorker.cpp" line="57"/>
        <source>Input MSA</source>
        <translation>Входное МВ</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="57"/>
        <source>Input MSA to process.</source>
        <translation>Множественное выравнивание последовательностей для обработки.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="58"/>
        <source>Kalign result MSA</source>
        <translation>Результат выравнивания МВ c помощью Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="59"/>
        <source>The result of the Kalign alignment.</source>
        <translation>Результат выравнивания с помощью Kalign.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="68"/>
        <source>Gap open penalty</source>
        <translation>Штраф за открытие пробела</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="69"/>
        <source>The penalty for opening/closing a gap. Half the value will be subtracted from the alignment score when opening, and half when closing a gap.</source>
        <translation>Штраф за открытие/закрытие пробела. Половина значения будет вычитаться из результата выравнивания при открытии, и половина при закрытии пробела.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="70"/>
        <source>Gap extension penalty</source>
        <translation>Штраф за промежуточный пробел</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="71"/>
        <source>The penalty for extending a gap.</source>
        <translation>Штраф за открытие пробела.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="72"/>
        <source>Terminal gap penalty</source>
        <translation>Штраф за закрытие пробела</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="73"/>
        <source>The penalty to extend gaps from the N/C terminal of protein or 5&apos;/3&apos; terminal of nucleotide sequences.</source>
        <translation>Штраф за расширение пробела терминала N/C для белков или терминала 5&apos;/3&apos; для нуклеотидных последовательностей.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="74"/>
        <source>Bonus score</source>
        <translation>Бонусные очки</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="75"/>
        <source>A bonus score that is added to each pair of aligned residues.</source>
        <translation>Бонусное значение, которое добавляется к матрице подстановок.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="82"/>
        <source>Align with Kalign</source>
        <translation>Выравнивание с помощью Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="83"/>
        <source>Aligns multiple sequence alignments (MSAs) supplied with Kalign.&lt;p&gt;Kalign is a fast and accurate multiple sequence alignment tool. The original version of the tool can be found on &lt;a href=&quot;http://msa-&gt;sbc.su.se&quot;&gt;http://msa-&gt;sbc.su.se&lt;/a&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aligns multiple sequence alignments (MSAs) supplied with Kalign.&lt;p&gt;Kalign is a fast and accurate multiple sequence alignment tool. The original version of the tool can be found on &lt;a href=&quot;http://msa.sbc.su.se&quot;&gt;http://msa.sbc.su.se&lt;/a&gt;.</source>
        <translation type="vanished">Для каждого множественного выравнивания (МВ) применяет Kalign.
&lt;p&gt;Kalign это быстрый и точный алгоритм множественного выравнивания последовательности. 
Здесь &lt;a href=&quot;http://msa.sbc.su.se&quot;&gt;http://msa.sbc.su.se&lt;/a&gt; находится оригинальная версия.       </translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="159"/>
        <source>An empty MSA &apos;%1&apos; has been supplied to Kalign.</source>
        <translation>Kalign получил пустое МВ &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="187"/>
        <source>Aligned %1 with Kalign</source>
        <translation>%1 выровнено с Kalign</translation>
    </message>
</context>
</TS>

==> ugene_34.0+dfsg.orig.tar.xz: ugene-34.0/src/plugins_3rdparty/kalign/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>KalignDialog</name>
    <message>
        <location filename="../src/KalignDialog.ui" line="32"/>
        <source>Align with Kalign</source>
        <translation>Выравнивание с помощью Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="46"/>
        <source>Input and output</source>
        <translation>Входные и выходные данные</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="54"/>
        <source>Input file</source>
        <translation>Входной файл</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="64"/>
        <location filename="../src/KalignDialog.ui" line="81"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="71"/>
        <location filename="../src/KalignDialog.ui" line="307"/>
        <source>Output file</source>
        <translation>Выходной файл</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="99"/>
        <source>Advanced options</source>
        <translation>Дополнительные опции</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="114"/>
        <source>Gap open penalty</source>
        <translation>Штраф за открытие пробела</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="160"/>
        <source>Gap extension penalty</source>
        <translation>Штраф за промежуточный пробел</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="206"/>
        <source>Terminal gap penalty</source>
        <translation>Штраф за закрытие пробела</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="252"/>
        <source>Bonus score</source>
        <translation>Бонусные очки</translation>
    </message>
    <message>
        <location filename="../src/KalignDialog.ui" line="295"/>
        <source>Translate to amino when aligning</source>
        <translation>Транслировать в амины в процессе выравнивания</translation>
    </message>
</context>
<context>
    <name>PairwiseAlignmentHirschbergOptionsPanelMainWidget</name>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="37"/>
        <source>Gap open penalty</source>
        <translation>Штраф за открытие пробела</translation>
    </message>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="57"/>
        <source>Gap extension penalty</source>
        <translation>Штраф за промежуточный пробел</translation>
    </message>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="77"/>
        <source>Terminate gap penalty</source>
        <translation>Штраф за закрытие пробела</translation>
    </message>
    <message>
        <location filename="../src/PairwiseAlignmentHirschbergOptionsPanelMainWidget.ui" line="97"/>
        <source>Bonus score</source>
        <translation>Бонусные очки</translation>
    </message>
</context>
<context>
    <name>U2::KalignAdapter</name>
    <message>
        <location filename="../src/KalignAdapter.cpp" line="54"/>
        <source>Internal Kalign error: %1</source>
        <translation>Внутренняя ошибка Kalign: %1</translation>
    </message>
</context>
<context>
    <name>U2::KalignAlignWithExtFileSpecifyDialogController</name>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="128"/>
        <source>Align</source>
        <translation>Выровнять</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="129"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="146"/>
        <source>Open an alignment file</source>
        <translation>Открыть выравнивание</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="160"/>
        <source>Save an multiple alignment file</source>
        <translation>Сохранить выранивание</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="193"/>
        <location filename="../src/KalignDialogController.cpp" line="196"/>
        <source>Kalign with Align</source>
        <translation>Выравнивание с помощью Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="194"/>
        <source>Input file is not set!</source>
        <translation>Входной файл не выбран!</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="197"/>
        <source>Output file is not set!</source>
        <translation>Выходной файл не указан!</translation>
    </message>
</context>
<context>
    <name>U2::KalignDialogController</name>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="63"/>
        <source>Align</source>
        <translation>Выровнять</translation>
    </message>
    <message>
        <location filename="../src/KalignDialogController.cpp" line="64"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>U2::KalignGObjectRunFromSchemaTask</name>
    <message>
        <location filename="../src/KalignTask.cpp" line="261"/>
        <source>Workflow wrapper &apos;%1&apos;</source>
        <translation>Workflow wrapper &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="271"/>
        <source>KAlign align &apos;%1&apos;</source>
        <translation>Выравнивание с помощью Kalign &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::KalignGObjectTask</name>
    <message>
        <location filename="../src/KalignTask.cpp" line="152"/>
        <source>KALIGN align &apos;%1&apos;</source>
        <translation>Выравнивание с помощью Kalign &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>U2::KalignMSAEditorContext</name>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="153"/>
        <source>Align with Kalign...</source>
        <translation>Выравнивание с помощью Kalign...</translation>
    </message>
</context>
<context>
    <name>U2::KalignPlugin</name>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="71"/>
        <source>Kalign</source>
        <translation>Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="72"/>
        <source>A port of Kalign package for multiple sequence alignment. Check http://msa.sbc.su.se for the original version</source>
        <translation>Встроенный в UGENE программный пакет для множественного выравнивания последовательности. Здесь http://msa.sbc.su.se находится оригинальная версия</translation>
    </message>
    <message>
        <location filename="../src/KalignPlugin.cpp" line="82"/>
        <source>Align with Kalign...</source>
        <translation>Выравнивание с помощью Kalign...</translation>
    </message>
</context>
<context>
    <name>U2::KalignTask</name>
    <message>
        <location filename="../src/KalignTask.cpp" line="73"/>
        <source>KALIGN alignment</source>
        <translation>Выравнивание с помощью Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="93"/>
        <source>Unsupported alphabet: %1</source>
        <translation>Неподдерживаемый алфавит: %1</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="96"/>
        <source>Kalign alignment started</source>
        <translation>Kalign alignment started</translation>
    </message>
    <message>
        <location filename="../src/KalignTask.cpp" line="101"/>
        <source>Kalign alignment successfully finished</source>
        <translation>Kalign alignment successfully finished</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::KalignPrompter</name>
    <message>
        <location filename="../src/KalignWorker.cpp" line="121"/>
        <source> from %1</source>
        <translation> из %1</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="123"/>
        <source>Aligns each MSA supplied &lt;u&gt;%1&lt;/u&gt; with &quot;&lt;u&gt;Kalign&lt;/u&gt;&quot;.</source>
        <translation>Для каждого МВ &lt;u&gt;%1&lt;/u&gt;, построить выравнивание с использованием &lt;u&gt;&quot;Kalign&quot;&lt;/u&gt;.</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::KalignWorker</name>
    <message>
        <location filename="../src/KalignWorker.cpp" line="57"/>
        <source>Input MSA</source>
        <translation>Входное МВ</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="57"/>
        <source>Input MSA to process.</source>
        <translation>Множественное выравнивание последовательностей для обработки.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="58"/>
        <source>Kalign result MSA</source>
        <translation>Результат выравнивания МВ c помощью Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="59"/>
        <source>The result of the Kalign alignment.</source>
        <translation>Результат выравнивания с помощью Kalign.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="68"/>
        <source>Gap open penalty</source>
        <translation>Штраф за открытие пробела</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="69"/>
        <source>The penalty for opening/closing a gap. Half the value will be subtracted from the alignment score when opening, and half when closing a gap.</source>
        <translation>Штраф за открытие/закрытие пробела. Половина значения будет вычитаться из результата выравнивания при открытии, и половина при закрытии пробела.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="70"/>
        <source>Gap extension penalty</source>
        <translation>Штраф за промежуточный пробел</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="71"/>
        <source>The penalty for extending a gap.</source>
        <translation>Штраф за открытие пробела.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="72"/>
        <source>Terminal gap penalty</source>
        <translation>Штраф за закрытие пробела</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="73"/>
        <source>The penalty to extend gaps from the N/C terminal of protein or 5&apos;/3&apos; terminal of nucleotide sequences.</source>
        <translation>Штраф за расширение пробела терминала N/C для белков или терминала 5&apos;/3&apos; для нуклеотидных последовательностей.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="74"/>
        <source>Bonus score</source>
        <translation>Бонусные очки</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="75"/>
        <source>A bonus score that is added to each pair of aligned residues.</source>
        <translation>Бонусное значение, которое добавляется к матрице подстановок.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="82"/>
        <source>Align with Kalign</source>
        <translation>Выравнивание с помощью Kalign</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="83"/>
        <source>Aligns multiple sequence alignments (MSAs) supplied with Kalign.&lt;p&gt;Kalign is a fast and accurate multiple sequence alignment tool. The original version of the tool can be found on &lt;a href=&quot;http://msa-&gt;sbc.su.se&quot;&gt;http://msa-&gt;sbc.su.se&lt;/a&gt;.</source>
        <translation>Для каждого множественного выравнивания (МВ) применяет Kalign.
&lt;p&gt;Kalign это быстрый и точный алгоритм множественного выравнивания последовательности. 
Здесь &lt;a href=&quot;http://msa.sbc.su.se&quot;&gt;http://msa.sbc.su.se&lt;/a&gt; находится оригинальная версия.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="159"/>
        <source>An empty MSA &apos;%1&apos; has been supplied to Kalign.</source>
        <translation>Kalign получил пустое МВ &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/KalignWorker.cpp" line="187"/>
        <source>Aligned %1 with Kalign</source>
        <translation>%1 выровнено с Kalign</translation>
    </message>
</context>
</TS>
